Caylir v0.1.0
Modules summary ↑
| Caylir.Graph | Base module to define graph connections |
| Caylir.Graph.Connection | Module to handle the connection between a graph module and a graph worker |
| Caylir.Graph.Response | Helper module to decode graph responses |
| Caylir.Graph.URL | Utility module to generate the URLs for graph interaction |
| Caylir.Graph.Worker | Worker module for direct communication with the graph |